@@ -10,31 +10,26 @@ class MjpegParser(object):
     self.pil = True
     self.quality = 50
     self.format = 'jpeg'
-    self.input = ''
-    self.timeout = 1
-    self.ping = False
-
     try:
-      logging.debug("Now trying to open the connection to the camera")
-      self.input = urllib2.urlopen(url, self.timeout)
+      self.input = urllib2.urlopen(url)
       self.ping = True
     except:
-      # maybe I should raise an exception here ???
-      # raise Exception('The camera is offline or the url is not good')
-      logging.error("The camera is offline or the url is not good")
+      logging.error('input error')
       self.ping = False
 
     self.length = 0
-    # mimic the same data as the origin input, good if you are streaming as-is
+    # Mimic the same data as the origin input, good if you are streaming as-is.
     self.data = ''
     self.headers = self.get_headers()
 
+
   # Default headers when serving to the client as mjpeg
   def get_headers(self):
-    return '\r\n' + '--ipcamera\r\n' + 'Content-Length: ' + str(self.length) +  '\r\n' + 'Content-Type: image/jpeg\r\n' + '\r\n'
+    return '\r\n' + '--ipcamera\r\n' + 'Content-Length: ' + str(self.length) + \
+    '\r\n' + 'Content-Type: image/jpeg\r\n' + '\r\n'
 
   def serve(self):
-    # Regex for digits in content-length
+    # Regex for digits in content-length.
     regex = re.compile("\d+")
     # Declare some empty vars with init values for while loop.
     content_length = 0
@@ -42,10 +37,10 @@ class MjpegParser(object):
     content = ''
     self.data = ''
 
+
     # loop until it contains: content_length and content-type
     while content_length == 0 or content_type == 0:
-
-      # pick up the content-length.
+      # Pick up the content-length.
       if 'content-length' in content.lower():
         length = regex.findall(content)
         if len(length) >= 1:
@@ -56,10 +51,9 @@ class MjpegParser(object):
 
       # Nothing found startover.
       content = self.input.readline()
-      logging.log("data ==> %s", content)
 
     data = self.input.read(content_length)
-    self.data += content # Slow need to use join instead (pep8 Style)
+    self.data += content # Slow need to use join instead (pep8 Style).
     self.output = StringIO.StringIO()
     self.length = self.output.len
     self.filename = 'cameraphoto.jpg'
@@ -68,7 +62,8 @@ class MjpegParser(object):
     if self.pil:
       from PIL import Image
       self.im = Image.open(io.BytesIO(data))
-      # if you need to do more changes to the image use overide the image_manipulator
+      # If you need to do more changes to the image.
+      # Use overide the image_manipulator.
       self.image_manipulator(self.im)
       self.im.save(self.output, format=self.format, quality=self.quality)
       self.output.seek(0)
@@ -79,12 +74,13 @@ class MjpegParser(object):
     self.length = self.output.len
     return self
 
-  # Overide this method to do more image manipulations
+  # Overide this method to do more image manipulations.
   def image_manipulator(self, image):
     '''You can manipulate your image here in example :
     from PIL import ImageDraw
     draw = ImageDraw.Draw(self.im)
-    draw.text((0, 0), str(time.ctime()) + " Your Camera name : " , (255, 255, 255))
+    draw.text((0, 0), str(time.ctime()) + " Your Camera name : " \
+    , (255, 255, 255))
     '''
     pass
 
